# CHANGELOG

## [v1.0.1a](https://github.com/orkhanshirin/biocli/releases/tag/v1.0.1a) - 2022-09-21 15:53:38

*No description*

\* *This CHANGELOG was automatically generated by [auto-generate-changelog](https://github.com/BobAnkh/auto-generate-changelog)*
